Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Bytes ¶
type Bytes struct {
FlowCounter
}
type DynamicIFace ¶ added in v0.5.2
type DynamicIFace interface {
Topic() string
// Retained used by topics provider to get retained message when there is new subscription to given topic
Retained() *mqttp.Publish
// Publish used by systree update routine to publish new value when on periodic basis
Publish() *mqttp.Publish
Add(uint64) uint64
Set(uint64)
Get() uint64
}
DynamicIFace interface describes states of the dynamic value
type FlowCounter ¶
func (*FlowCounter) Diff ¶
func (c *FlowCounter) Diff(prev *FlowCounter) FlowCounter
func (*FlowCounter) RecvAddU64 ¶
func (c *FlowCounter) RecvAddU64(n uint64) uint64
func (*FlowCounter) SentAddU64 ¶
func (c *FlowCounter) SentAddU64(n uint64) uint64
type Packets ¶
type Packets struct {
Total FlowCounter
Connect Counter
ConnAck Counter
Publish FlowCounter
Puback FlowCounter
Pubrec FlowCounter
Pubrel FlowCounter
Pubcomp FlowCounter
Sub Counter
SubAck Counter
UnSub Counter
UnSubAck Counter
Disconnect FlowCounter
PingReq Counter
PingResp Counter
Auth FlowCounter
Unknown Counter
Rejected Counter
UnAckSent Max
UnAckRecv Max
Retained Max
Stored Max
}
type Subscriptions ¶
type Subscriptions struct {
Total Max
}
Click to show internal directories.
Click to hide internal directories.